%undefine __cmake_in_source_build
%undefine __cmake3_in_source_build

%bcond_with tests

Name:               gfal2
Version:            2.22.2
Release:    2%{?dist}
Summary:            Grid file access library 2.0
License:            ASL 2.0
URL:                https://dmc-docs.web.cern.ch/dmc-docs/gfal2/gfal2.html
Source0:            %{name}-%{version}.tar.gz

BuildRequires:      gcc-c++
BuildRequires:      cmake3
BuildRequires:      doxygen
BuildRequires:      json-c-devel
BuildRequires:      glib2-devel >= 2.28
Requires:           glib2 >= 2.28
BuildRequires:      libattr-devel
BuildRequires:      openldap-devel
BuildRequires:      pugixml-devel
BuildRequires:      libuuid-devel
BuildRequires:      zlib-devel
BuildRequires:      srm-ifce-devel >= 1.23.1
BuildRequires:      dcap-devel
BuildRequires:      globus-gass-copy-devel
BuildRequires:      davix-devel >= 0.8.4
BuildRequires:      cryptopp-devel >= 5.6.2
BuildRequires:      xrootd-client-devel >= 5.0.0
BuildRequires:      libssh2-devel
BuildRequires:      gtest-devel

Provides:           %{name}-core = %{version}-%{release}
Provides:           %{name}-transfer = %{version}-%{release}

%description
GFAL 2.0 offers an a single and simple POSIX-like API
for the file operations in grids and cloud environments.
The set of supported protocols depends
of the %{name} installed plugins.

%package devel
Summary:            Development files of %{name}
Requires:           %{name} = %{version}-%{release}
Requires:           glib2-devel
Requires:           libattr-devel
Requires:           pkgconfig

%description devel
development files for %{name}

%package doc
Summary:            Documentation for %{name}
BuildArch:          noarch

%description doc
Documentation, Doxygen and examples of %{name}.


%package plugin-file
Summary:            Provides file support for %{name}
Requires:           %{name} = %{version}-%{release}

%description plugin-file
Provides the file support (file://) for %{name}.
The file plugin provides local file operations, as copying from local
to remote or the other way around.


%package plugin-dcap
Summary:            Provides the support access for %{name}
Requires:           %{name} = %{version}-%{release}
Requires:           dcap-tunnel-gsi

%description plugin-dcap
Provides the dcap support (gsidcap://, dcap://) for %{name}.
The dcap plugin provides the POSIX operations for the dcap \
URLs, the dcap protocol is used on the DCACHE storage system


%package plugin-srm
Summary:            Provides the srm access for %{name}
Requires:           %{name} = %{version}-%{release}
Requires:           srm-ifce >= 1.23.1

%description plugin-srm
Provides the srm support (srm://) for %{name}.
The srm plugin provides the POSIX operations and
the third party transfer support on the SRM URLs.


%package plugin-gridftp
Summary:            Provides the gridftp support for %{name}
Requires:           %{name} = %{version}-%{release}

%description plugin-gridftp
Provides the gridftp support (gsiftp://) for %{name}.
The gridftp plugin provides the POSIX operations and
the third party transfer support on the GSIFTP URLs.


%package plugin-http
Summary:            Provides the HTTP/DAV support for %{name}
Requires:           %{name} = %{version}-%{release}
Requires:           davix-libs >= 0.8.4

%description plugin-http
Provides the HTTP (http[s]://) and WevDAV (dav[s]://) support for %{name}.
This plugin is able to do Third-Party Copy with WebDAV,
if the storage supports it.


%package plugin-xrootd
Summary:            Provide xrootd support for GFAL2
Requires:           %{name} = %{version}-%{release}

%description plugin-xrootd
The Grid File Access Library, GFAL2, provides a simple POSIX-like API for file
operations in grid and cloud environments. Plug-ins are available to allow
access via a variety of protocols. This package contains a plugin for the
xrootd protocol (root://).

%package plugin-sftp
Summary:            Provide sftp support for GFAL2
Requires:           %{name} = %{version}-%{release}

%description plugin-sftp
The Grid File Access Library, GFAL2, provides a simple POSIX-like API for file
operations in grid and cloud environments. Plug-ins are available to allow
access via a variety of protocols. This package contains a plugin for the
sftp protocol (sftp://).

%package plugin-mock
Summary:            Provides a Mock dummy protocol for %{name}
Requires:           %{name} = %{version}-%{release}

%description plugin-mock
Provides a dummy mock:// protocol for %{name}.


%package all
Summary:            Meta package for GFAL 2.0 install
Requires:           %{name} = %{version}-%{release}
Requires:           %{name}-plugin-file = %{version}-%{release}
Requires:           %{name}-plugin-dcap = %{version}-%{release}
Requires:           %{name}-plugin-srm = %{version}-%{release}
Requires:           %{name}-plugin-gridftp = %{version}-%{release}
Requires:           %{name}-plugin-http = %{version}-%{release}
Requires:           %{name}-plugin-xrootd = %{version}-%{release}
Requires:           %{name}-plugin-sftp = %{version}-%{release}

%description all
Meta-package for complete install of GFAL2
with all the protocol plugins.

%package tests
Summary:            gfal2 tests
Requires:           gfal2-all = %{version}-%{release}
Requires:           gfal2-plugin-mock = %{version}-%{release}

%description tests
gfal2 tests

%clean
%cmake3_build --target clean

%prep
%autosetup

%build
gfal2_cmake_ver=`sed -n 's/^set *(VERSION_\(MAJOR\|MINOR\|PATCH\) \+\([0-9]\+\).*/\2/p' CMakeLists.txt | paste -sd '.'`
gfal2_spec_ver=`expr "%{version}" : '\([0-9]*\\.[0-9]*\\.[0-9]*\)'`
if [ "$gfal2_cmake_ver" != "$gfal2_spec_ver" ]; then
    echo "The version in the spec file does not match the CMakeLists.txt version!"
    echo "$gfal2_cmake_ver != %{version}"
    exit 1
fi

%cmake3 \
    -DDOC_INSTALL_DIR=%{_pkgdocdir} \
    -DUNIT_TESTS=TRUE \
    -DPLUGIN_MOCK=TRUE \
    -DPLUGIN_LFC=FALSE \
    -DPLUGIN_RFIO=FALSE \
    -DFUNCTIONAL_TESTS=%{?with_tests:ON}%{?!with_tests:OFF}

%cmake3_build
%cmake3_build --target doc

%install
%cmake3_install

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig


%files
%{_bindir}/gfal2_version
%{_libdir}/libgfal2.so.*
%{_libdir}/libgfal_transfer.so.*
%dir %{_libdir}/%{name}-plugins
%dir %{_sysconfdir}/%{name}.d
%config(noreplace) %{_sysconfdir}/%{name}.d/bdii.conf
%config(noreplace) %{_sysconfdir}/%{name}.d/gfal2_core.conf
%config(noreplace) %{_sysconfdir}/%{name}.d/x509.conf

%{_mandir}/man1/gfal2_version.1*
%dir %{_pkgdocdir}
%{_pkgdocdir}/DESCRIPTION
%{_pkgdocdir}/README.md
%{_pkgdocdir}/LICENSE
%{_pkgdocdir}/RELEASE-NOTES

%files devel
%{_includedir}/%{name}/
%{_libdir}/pkgconfig/gfal2.pc
%{_libdir}/pkgconfig/gfal_transfer.pc
%{_libdir}/libgfal2.so
%{_libdir}/libgfal_transfer.so

%files doc
%{_pkgdocdir}/readme.html
%{_pkgdocdir}/html/
%{_pkgdocdir}/examples/

%files plugin-file
%{_libdir}/%{name}-plugins/libgfal_plugin_file.so*
%{_pkgdocdir}/README_PLUGIN_FILE


%files plugin-dcap
%{_libdir}/%{name}-plugins/libgfal_plugin_dcap.so*
%{_pkgdocdir}/README_PLUGIN_DCAP
%config(noreplace) %{_sysconfdir}/%{name}.d/dcap_plugin.conf

%files plugin-srm
%{_libdir}/%{name}-plugins/libgfal_plugin_srm.so*
%{_pkgdocdir}/README_PLUGIN_SRM
%config(noreplace) %{_sysconfdir}/%{name}.d/srm_plugin.conf

%files plugin-gridftp
%{_libdir}/%{name}-plugins/libgfal_plugin_gridftp.so*
%{_pkgdocdir}/README_PLUGIN_GRIDFTP
%config(noreplace) %{_sysconfdir}/%{name}.d/gsiftp_plugin.conf

%files plugin-http
%{_libdir}/%{name}-plugins/libgfal_plugin_http.so*
%{_pkgdocdir}/README_PLUGIN_HTTP
%config(noreplace) %{_sysconfdir}/%{name}.d/http_plugin.conf

%files plugin-xrootd
%{_libdir}/%{name}-plugins/libgfal_plugin_xrootd.so*
%{_pkgdocdir}/README_PLUGIN_XROOTD
%config(noreplace) %{_sysconfdir}/%{name}.d/xrootd_plugin.conf

%files plugin-sftp
%{_libdir}/%{name}-plugins/libgfal_plugin_sftp.so*
%{_pkgdocdir}/README_PLUGIN_SFTP
%config(noreplace) %{_sysconfdir}/%{name}.d/sftp_plugin.conf

%files plugin-mock
%{_libdir}/%{name}-plugins/libgfal_plugin_mock.so*
%{_pkgdocdir}/README_PLUGIN_MOCK
%config(noreplace) %{_sysconfdir}/%{name}.d/mock_plugin.conf

%files tests
%{_bindir}/gfal2-unit-tests
%{_libdir}/libgfal2_test_shared.so

%files all


%changelog
* Thu Jun 05 2025 bbrucezhang <bbrucezhang@tencent.com> - 2.22.2-2
- Rebuilt for loongarch64

* Wed Jul 24 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.22.2-1
- initial build
